@@ -120,13 +120,13 @@ END
 
 my $result=sub {
 
-   my $demo_choice=']P[{choose_demo_setup}';
-   $demo_choice=~s/^["]//;
-   $demo_choice=~s/["]$//;
-   my $iset=$Net::FullAuto::ISets->{$demo_choice};
-   $Net::FullAuto::ISets->{selected_iset}=$demo_choice;
-   my $result=$Net::FullAuto::ISets->{$demo_choice}->[1]."select_".
-              lc($Net::FullAuto::ISets->{$demo_choice}->[2]).
+   my $iset_choice=']P[{choose_iset_setup}';
+   $iset_choice=~s/^["]//;
+   $iset_choice=~s/["]$//;
+   my $iset=$Net::FullAuto::ISets->{$iset_choice};
+   $Net::FullAuto::ISets->{selected_iset}=$iset_choice;
+   my $result=$Net::FullAuto::ISets->{$iset_choice}->[1]."select_".
+              lc($Net::FullAuto::ISets->{$iset_choice}->[2]).
               "_setup";
    eval "\$result=$result";
    return $result->();
@@ -137,7 +137,7 @@ my $get_isets=sub {
 
    print "\n";
    my ($output,$error)=('','');
-   my $choose_demo_banner=<<'END';
+   my $choose_iset_banner=<<'END';
      ___ _
     / __| |_  ___  ___ ___ ___    __ _ _ _
    | (__| ' \/ _ \/ _ (_-</ -_)  / _` | ' \
@@ -149,15 +149,15 @@ my $get_isets=sub {
    |___|_||_/__/\__|_|  \_,_\__|\__|_\___/_||_|  |___/\___|\__|
 
 
-   Below is a selection of demos designed to demonstrate
-   FullAuto's unique ability to automate *any* cloud
+   Below is a selection of FullAuto Instruction Sets that
+   engage FullAuto's unique ability to automate *any* cloud
    computing operation. Please choose one:
 
 END
    my $dirtree=Net::FullAuto::FA_Core::get_isets('Local');
-   my %choose_demo_setup=(
+   my %choose_iset_setup=(
 
-      Name => 'choose_demo_setup',
+      Name => 'choose_iset_setup',
       Item_1 => {
 
          Text   => ']C[',
@@ -166,10 +166,10 @@ END
 
       },
       Scroll => 1,
-      Banner => $choose_demo_banner,
+      Banner => $choose_iset_banner,
 
    );
-   return \%choose_demo_setup;
+   return \%choose_iset_setup;
 };
 
 sub iset {
@@ -184,7 +184,7 @@ sub iset {
 
    You are fully authenticated with FullAuto on LocalHost.
 
-   The goal now is to demonstrate how FullAuto can fully automate the
+   The goal now is to use FullAuto to fully automate the
    setup, processing and maintenance of cloud computing.
 
 END
